#[repr(C)]pub struct PerpetualContract {Show 27 fields
pub id: InstrumentId,
pub raw_symbol: Symbol,
pub underlying: Ustr,
pub asset_class: AssetClass,
pub base_currency: Option<Currency>,
pub quote_currency: Currency,
pub settlement_currency: Currency,
pub is_inverse: bool,
pub price_precision: u8,
pub size_precision: u8,
pub price_increment: Price,
pub size_increment: Quantity,
pub multiplier: Quantity,
pub lot_size: Quantity,
pub margin_init: Decimal,
pub margin_maint: Decimal,
pub maker_fee: Decimal,
pub taker_fee: Decimal,
pub max_quantity: Option<Quantity>,
pub min_quantity: Option<Quantity>,
pub max_notional: Option<Money>,
pub min_notional: Option<Money>,
pub max_price: Option<Price>,
pub min_price: Option<Price>,
pub info: Option<Params>,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents a perpetual contract instrument (perpetual swap).
Supports perpetuals on any asset class including FX, equities, commodities, indexes, and cryptocurrencies.
Fields
id: InstrumentIdThe instrument ID for the instrument.
raw_symbol: SymbolThe raw/local/native symbol for the instrument, assigned by the venue.
underlying: UstrThe underlying asset identifier (e.g., “EURUSD”, “NVDA”, “GC”).
asset_class: AssetClassThe asset class of the perpetual contract.
base_currency: Option<Currency>The base currency (optional, set for FX/crypto underlyings).
quote_currency: CurrencyThe quote currency.
settlement_currency: CurrencyThe settlement currency.
is_inverse: boolIf the instrument costing is inverse (quantity expressed in quote currency units).
price_precision: u8The price decimal precision.
size_precision: u8The trading size decimal precision.
price_increment: PriceThe minimum price increment (tick size).
size_increment: QuantityThe minimum size increment.
multiplier: QuantityThe contract multiplier.
lot_size: QuantityThe rounded lot unit size (standard/board).
margin_init: DecimalThe initial (order) margin requirement in percentage of order value.
margin_maint: DecimalThe maintenance (position) margin in percentage of position value.
maker_fee: DecimalThe fee rate for liquidity makers as a percentage of order value.
taker_fee: DecimalThe fee rate for liquidity takers as a percentage of order value.
max_quantity: Option<Quantity>The maximum allowable order quantity.
min_quantity: Option<Quantity>The minimum allowable order quantity.
max_notional: Option<Money>The maximum allowable order notional value.
min_notional: Option<Money>The minimum allowable order notional value.
max_price: Option<Price>The maximum allowable quoted price.
min_price: Option<Price>The minimum allowable quoted price.
info: Option<Params>Additional instrument metadata as a JSON-serializable dictionary.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the data event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the data object was initialized.
Implementations
Sourceimpl PerpetualContract
impl PerpetualContract
Sourcepub fn new_checked(
instrument_id: InstrumentId,
raw_symbol: Symbol,
underlying: Ustr,
asset_class: AssetClass,
base_currency: Option<Currency>,
quote_currency: Currency,
settlement_currency: Currency,
is_inverse: bool,
price_precision: u8,
size_precision: u8,
price_increment: Price,
size_increment: Quantity,
multiplier: Option<Quantity>,
lot_size: Option<Quantity>,
max_quantity: Option<Quantity>,
min_quantity: Option<Quantity>,
max_notional: Option<Money>,
min_notional: Option<Money>,
max_price: Option<Price>,
min_price: Option<Price>,
margin_init: Option<Decimal>,
margin_maint: Option<Decimal>,
maker_fee: Option<Decimal>,
taker_fee: Option<Decimal>,
info: Option<Params>,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> CorrectnessResult<Self>
pub fn new_checked( instrument_id: InstrumentId, raw_symbol: Symbol, underlying: Ustr, asset_class: AssetClass, base_currency: Option<Currency>, quote_currency: Currency, settlement_currency: Currency, is_inverse: bool, price_precision: u8, size_precision: u8, price_increment: Price, size_increment: Quantity, multiplier: Option<Quantity>, lot_size: Option<Quantity>, max_quantity: Option<Quantity>, min_quantity: Option<Quantity>, max_notional: Option<Money>, min_notional: Option<Money>, max_price: Option<Price>, min_price: Option<Price>, margin_init: Option<Decimal>, margin_maint: Option<Decimal>, maker_fee: Option<Decimal>, taker_fee: Option<Decimal>, info: Option<Params>, ts_event: UnixNanos, ts_init: UnixNanos, ) -> CorrectnessResult<Self>
Creates a new PerpetualContract instance with correctness checking.
Notes
PyO3 requires a Result type for proper error handling and stacktrace printing in Python.
Errors
Returns an error if any input validation fails.
Sourcepub fn new(
instrument_id: InstrumentId,
raw_symbol: Symbol,
underlying: Ustr,
asset_class: AssetClass,
base_currency: Option<Currency>,
quote_currency: Currency,
settlement_currency: Currency,
is_inverse: bool,
price_precision: u8,
size_precision: u8,
price_increment: Price,
size_increment: Quantity,
multiplier: Option<Quantity>,
lot_size: Option<Quantity>,
max_quantity: Option<Quantity>,
min_quantity: Option<Quantity>,
max_notional: Option<Money>,
min_notional: Option<Money>,
max_price: Option<Price>,
min_price: Option<Price>,
margin_init: Option<Decimal>,
margin_maint: Option<Decimal>,
maker_fee: Option<Decimal>,
taker_fee: Option<Decimal>,
info: Option<Params>,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub fn new( instrument_id: InstrumentId, raw_symbol: Symbol, underlying: Ustr, asset_class: AssetClass, base_currency: Option<Currency>, quote_currency: Currency, settlement_currency: Currency, is_inverse: bool, price_precision: u8, size_precision: u8, price_increment: Price, size_increment: Quantity, multiplier: Option<Quantity>, lot_size: Option<Quantity>, max_quantity: Option<Quantity>, min_quantity: Option<Quantity>, max_notional: Option<Money>, min_notional: Option<Money>, max_price: Option<Price>, min_price: Option<Price>, margin_init: Option<Decimal>, margin_maint: Option<Decimal>, maker_fee: Option<Decimal>, taker_fee: Option<Decimal>, info: Option<Params>, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self
Creates a new PerpetualContract instance.
Panics
Panics if any input parameter is invalid (see new_checked).